/**
 *
 */
package de.intevation.gnv.state.layer;
/**
 * Beanclass for storing Metainformation to create Shapefiles or Layer
 * in an WMS-Output.
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 *
 */
public class LayerMetaData {

    private String table = null;
    private String geometryType = null;
    private String where = null;
    private String columns = null;
    private String templateID = null;
    private String[] queryValues = null;
    private String geometryWKT = null;

    /**
     * Constructor
     * @param table the Name of the Databasetable the Data should be fetched from.
     * @param geometryType the Geometrytype of the Layer
     * @param where the Query-Statement which should be used to fetch the Data.
     * @param columns the Columnnames which should be fetched to generate the
     *                Shapefile
     * @param templateID the Id of the Template which should be used to create
     *                   the Mapfileentry.
     * @param queryValues the Values that should be used to Query the data
     * @param geometryWKT The Geometry represented by as an WKT to Query the Data.
     */
    public LayerMetaData(String table, String geometryType, String where,
                         String columns, String templateID,
                         String[] queryValues,String geometryWKT) {
        super();
        this.table = table;
        this.geometryType = geometryType;
        this.where = where;
        this.columns = columns;
        this.templateID = templateID;
        this.queryValues = queryValues;
        this.geometryWKT = geometryWKT;
    }

    /**
     *  Returns the Geometry WKT
     * @return  the Geometry WKT
     */
    public String getGeometryWKT() {
        return geometryWKT;
    }

    /**
     * Returns the Name of the Databasetable the Data should be fetched from.
     * @return the Name of the Databasetable the Data should be fetched from.
     */
    public String getTable() {
        return table;
    }

    /**
     * Returns the Geometrytype of the Layer.
     * @return the Geometrytype of the Layer.
     */
    public String getGeometryType() {
        return geometryType;
    }

    /**
     * Returns the Query-Statement which should be used to fetch the Data.
     * @return the Query-Statement which should be used to fetch the Data.
     */
    public String getWhere() {
        return where;
    }

    /**
     * Returns the Columnnames which should be fetched to generate the
     * Shapefile
     * @return the Columnnames which should be fetched to generate the
     *         Shapefile
     */
    public String getColumns() {
        return columns;
    }

    /**
     * Returns the Id of the Template which should be used to create
     * the Mapfileentry.
     * @return the Id of the Template which should be used to create
     *         the Mapfileentry.
     */
    public String getTemplateID() {
        return templateID;
    }

    /**
     * Returns the Values that should be used to Query the data.
     * @return the Values that should be used to Query the data.
     */
    public String[] getQueryValues() {
        return queryValues;
    }

}
