package de.intevation.gnv.transition;

import java.util.Map;

import org.apache.log4j.Logger;
import org.w3c.dom.Node;

import de.intevation.artifactdatabase.Config;
import de.intevation.gnv.state.InputData;
import de.intevation.gnv.state.State;

/**
 * Class which supports the possibility to validate if a
 * Transition could be done using simple Valuecompare Operations.
 * The Compareoperations will use the preSettings of an Artifact.
 * At this Time equal and notequal-operations are supported.
 * The Comparation is casesensitive.
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 *
 */
public class PresettingsValueCompareTransition extends TransitionBase {

    /**
     * the logger, used to log exceptions and additonaly information
     */
    private static Logger log = Logger.getLogger(PresettingsValueCompareTransition.class);

    /**
     * The Name of the Datafield the Value  that should be compared
     * should be fetched from.
     */
    private String dataName = null;
    /**
     * The Value that should be set to the State.
     */
    private String dataValue = null;
    /**
     * The Operation that should be used (equal notequal)
     */
    private String operator = null;

    /**
     * The UID of this Class.
     */
    private static final long serialVersionUID = -7846722158776823205L;

    /**
     * Constructor
     */
    public PresettingsValueCompareTransition() {
        super();
    }


    public boolean isValid(State state) {
        Map<String, InputData> preSettings = state.getPreSettings();
        if (preSettings != null){
            boolean dataAvailable = preSettings.containsKey(dataName);
            if (dataAvailable){
                if (operator.equals("equal")){
                    return preSettings.get(dataName).getValue().startsWith(dataValue);
                }else if (operator.equals("notequal")){
                    return !preSettings.get(dataName).getValue().startsWith(dataValue);
                }
            }
        }
        if (operator.equals("notequal")){
            return true;
        }
        return false;
    }


    @Override
    public void setup(Node configuration) {
        super.setup(configuration);
        this.dataName = Config.getStringXPath(configuration,"condition/@inputvalue");
        this.dataValue = Config.getStringXPath(configuration,"condition/@value");
        this.operator = Config.getStringXPath(configuration,"condition/@operator");
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
